@@ -6,19 +6,20 @@
 
 #include "testhelper.h"
 
-#include "statisticsmodel.h"
-#include "statisticstimerangemodel.h"
 #include "applicationcontroller.h"
 #include "importcontroller.h"
+#include "livedatamanager.h"
 #include "reservationmanager.h"
+#include "statisticsmodel.h"
+#include "statisticstimerangemodel.h"
 #include "transfermanager.h"
 #include "tripgroupmanager.h"
 
 #include <QAbstractItemModelTester>
-#include <QUrl>
-#include <QtTest/qtest.h>
 #include <QSignalSpy>
 #include <QStandardPaths>
+#include <QUrl>
+#include <QtTest/qtest.h>
 
 void initLocale()
 {
@@ -44,7 +45,9 @@ private Q_SLOTS:
     void testStats()
     {
         ReservationManager resMgr;
+        LiveDataManager ldm;
         TransferManager transferMgr;
+        transferMgr.setLiveDataManager(&ldm);
         Test::clearAll(&resMgr);
         TripGroupManager::clear();
         TripGroupManager tgMgr;
@@ -52,11 +55,13 @@ private Q_SLOTS:
         tgMgr.setTransferManager(&transferMgr);
         auto ctrl = Test::makeAppController();
         ctrl->setReservationManager(&resMgr);
+        ctrl->setTransferManager(&transferMgr);
 
         StatisticsModel stats;
         QSignalSpy changeSpy(&stats, &StatisticsModel::changed);
         stats.setReservationManager(&resMgr);
         stats.setTripGroupManager(&tgMgr);
+        stats.setTransferManager(&transferMgr);
 
         ImportController importer;
         importer.setReservationManager(&resMgr);
@@ -64,7 +69,8 @@ private Q_SLOTS:
         importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/akademy2017.json")));
         importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/../tests/akademy2018-program.json")));
         ctrl->commitImport(&importer);
-        importer.importFromUrl(QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/flight-cancelation.json"))); // canceled flight, should not change stats
+        importer.importFromUrl(
+            QUrl::fromLocalFile(QLatin1StringView(SOURCE_DIR "/data/timeline/flight-cancelation.json"))); // canceled flight, should not change stats
         ctrl->commitImport(&importer);
 
         stats.setTimeRange({}, {});
@@ -82,7 +88,7 @@ private Q_SLOTS:
         QCOMPARE(item.m_trend, StatisticsItem::TrendUnknown);
         QCOMPARE(item.m_hasData, true);
         item = stats.totalCO2();
-        QCOMPARE(item.m_value, QLatin1StringView("1,673 kg"));
+        QCOMPARE(item.m_value, QLatin1StringView("1,674 kg"));
         QCOMPARE(item.m_trend, StatisticsItem::TrendUnknown);
         QCOMPARE(item.m_hasData, true);
 
@@ -95,7 +101,7 @@ private Q_SLOTS:
         QCOMPARE(item.m_trend, StatisticsItem::TrendUnknown);
         QCOMPARE(item.m_hasData, true);
         item = stats.flightCO2();
-        QCOMPARE(item.m_value, QLatin1StringView("1,669 kg"));
+        QCOMPARE(item.m_value, QLatin1StringView("1,670 kg"));
         QCOMPARE(item.m_trend, StatisticsItem::TrendUnknown);
         QCOMPARE(item.m_hasData, true);
 
@@ -108,7 +114,7 @@ private Q_SLOTS:
         QCOMPARE(item.m_trend, StatisticsItem::TrendUnknown);
         QCOMPARE(item.m_hasData, true);
         item = stats.trainCO2();
-        QCOMPARE(item.m_value, QLatin1StringView("4.4 kg"));
+        QCOMPARE(item.m_value, QLatin1StringView("4.5 kg"));
         QCOMPARE(item.m_trend, StatisticsItem::TrendUnknown);
         QCOMPARE(item.m_hasData, true);
 
@@ -133,7 +139,7 @@ private Q_SLOTS:
         QCOMPARE(item.m_trend, StatisticsItem::TrendDown);
         QCOMPARE(item.m_hasData, true);
         item = stats.totalCO2();
-        QCOMPARE(item.m_value, QLatin1StringView("380 kg"));
+        QCOMPARE(item.m_value, QLatin1StringView("381 kg"));
         QCOMPARE(item.m_trend, StatisticsItem::TrendDown);
         QCOMPARE(item.m_hasData, true);
 
@@ -159,7 +165,7 @@ private Q_SLOTS:
         QCOMPARE(item.m_trend, StatisticsItem::TrendUp);
         QCOMPARE(item.m_hasData, true);
         item = stats.trainCO2();
-        QCOMPARE(item.m_value, QLatin1StringView("4.4 kg"));
+        QCOMPARE(item.m_value, QLatin1StringView("4.5 kg"));
         QCOMPARE(item.m_trend, StatisticsItem::TrendUp);
         QCOMPARE(item.m_hasData, true);
 
